@@ -1,7 +1,7 @@
 /*
  * Copyright 1993 OpenVision Technologies, Inc., All Rights Reserved.
  *
- * $Id: server.c 16467 2004-06-16 03:11:54Z tlyu $
+ * $Id: server.c 23100 2009-10-31 00:48:38Z tlyu $
  * $Source$
  */
 
@@ -9,8 +9,11 @@
 static char *rcsid = "$Header$";
 #endif
 
+#include "k5-platform.h"
+
 #include <stdio.h>
 #include <stdlib.h>
+#include "autoconf.h"
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -65,7 +68,7 @@ main(int argc, char **argv)
      extern int optind;
 #ifdef POSIX_SIGNALS
      struct sigaction sa;
-#endif     
+#endif
 
      names[0].name = SERVICE_NAME;
      names[0].type = (gss_OID) gss_nt_service_name;
@@ -115,13 +118,13 @@ main(int argc, char **argv)
 	  exit(1);
      }
      if (!svc_register(transp, RPC_TEST_PROG, RPC_TEST_VERS_1,
-		       rpc_test_prog_1_svc, prot)) { 
+		       rpc_test_prog_1_svc, prot)) {
 	  fprintf(stderr,
 		  "unable to register (RPC_TEST_PROG, RPC_TEST_VERS_1, %s).",
 		  prot == IPPROTO_TCP ? "tcp" : "udp");
 	  exit(1);
      }
-     
+
      if (svcauth_gssapi_set_names(names, 0) == FALSE) {
 	  fprintf(stderr, "unable to set gssapi names\n");
 	  exit(1);
@@ -144,7 +147,7 @@ main(int argc, char **argv)
      signal(SIGTERM, handlesig);
 #endif
      printf("running\n");
-     
+
      svc_run();
      fprintf(stderr, "svc_run returned");
      exit(1);
@@ -157,8 +160,7 @@ char **rpc_test_echo_1_svc(char **arg, struct svc_req *h)
 
      if (res)
 	  free(res);
-     res = (char *) malloc(strlen(*arg) + strlen("Echo: ") + 1);
-     sprintf(res, "Echo: %s", *arg);
+     asprintf(&res, "Echo: %s", *arg);
      return &res;
 }
 
@@ -175,7 +177,7 @@ static void rpc_test_badverf(gss_name_t client, gss_name_t server,
 
      printf("rpc_test server: bad verifier from %.*s at %s:%d for %.*s\n",
 	    (int) client_name.length, (char *) client_name.value,
-	    inet_ntoa(rqst->rq_xprt->xp_raddr.sin_addr), 
+	    inet_ntoa(rqst->rq_xprt->xp_raddr.sin_addr),
 	    ntohs(rqst->rq_xprt->xp_raddr.sin_port),
 	    (int) server_name.length, (char *) server_name.value);
 
@@ -203,7 +205,7 @@ void rpc_test_badauth(OM_uint32 major, OM_uint32 minor,
 		 struct sockaddr_in *addr, caddr_t data)
 {
      char *a;
-     
+
      /* Authentication attempt failed: <IP address>, <GSS-API error */
      /* strings> */
 
@@ -218,7 +220,7 @@ void log_miscerr(struct svc_req *rqst, struct rpc_msg *msg,
 		 char *error, char *data)
 {
      char *a;
-     
+
      a = inet_ntoa(rqst->rq_xprt->xp_raddr.sin_addr);
      printf("Miscellaneous RPC error: %s, %s\n", a, error);
 }
@@ -241,49 +243,20 @@ void log_badauth_display_status_1(OM_uint32 code, int type, int rec)
 				       &msg_ctx, &msg);
 	  if (gssstat != GSS_S_COMPLETE) {
  	       if (!rec) {
-		    log_badauth_display_status_1(gssstat,GSS_C_GSS_CODE,1); 
+		    log_badauth_display_status_1(gssstat,GSS_C_GSS_CODE,1);
 		    log_badauth_display_status_1(minor_stat,
 						 GSS_C_MECH_CODE, 1);
 	       } else
 		    printf("GSS-API authentication error %.*s: "
-			   "recursive failure!\n", (int) msg.length, 
+			   "recursive failure!\n", (int) msg.length,
 			   (char *)msg.value);
 	       return;
 	  }
-	  
-	  printf(", %.*s", (int) msg.length, (char *)msg.value); 
+
+	  printf(", %.*s", (int) msg.length, (char *)msg.value);
 	  (void) gss_release_buffer(&minor_stat, &msg);
-	  
+
 	  if (!msg_ctx)
 	       break;
      }
 }
-
-
-#if 0
-
-/* this hack is no longer necessary, since the library supports it
-   internally */
-
-/* This is a hack to change the default keytab name */
-
-#include <krb5/krb5.h>
-extern char *krb5_defkeyname;
-
-krb5_error_code
-krb5_kt_default_name(char *name, int namesize)
-{
-   char *ktname;
-
-   if ((ktname = getenv("KRB5KTNAME")) == NULL)
-      ktname = krb5_defkeyname;
-
-   if (namesize < strlen(ktname)+1)
-      return(KRB5_CONFIG_NOTENUFSPACE);
-
-   strcpy(name, ktname);
-
-   return(0);
-}
-
-#endif
