@@ -59,11 +59,11 @@ void kcdb_cred_exit(void)
     can be called by kcdb_cred_dup with a write lock on l_creds and in other
     places with a read lock on l_creds.  New credentials must be creatable while
     holding either lock. */
-KHMEXP khm_int32 KHMAPI 
-kcdb_cred_create(wchar_t *   name, 
+KHMEXP khm_int32 KHMAPI
+kcdb_cred_create(const wchar_t *   name,
                  khm_handle  identity,
                  khm_int32   cred_type,
-                 khm_handle * result) 
+                 khm_handle * result)
 {
     kcdb_cred * cred;
     size_t cb_name;
@@ -87,7 +87,7 @@ kcdb_cred_create(wchar_t *   name,
     cred->type = cred_type;
 
     cred->refcount = 1; /* initially held */
-    
+
     LINIT(cred);
 
     kcdb_buf_new(&cred->buf, KCDB_ATTR_MAX_ID + 1);
@@ -153,7 +153,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_update(khm_handle vdest,
                     goto _skip_copy;
             }
 
-            kcdb_buf_set_value(&dest->buf, i, i, srcbuf, cbsrcbuf);
+            kcdb_buf_set_value(&dest->buf, i, (khm_ui_2) i, srcbuf, cbsrcbuf);
             rv = KHM_ERROR_SUCCESS;
 
 	_skip_copy:
@@ -166,7 +166,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_update(khm_handle vdest,
 	    if (!(a->flags & KCDB_ATTR_FLAG_COMPUTED) &&
 		(a->flags & KCDB_ATTR_FLAG_TRANSIENT) &&
 		kcdb_cred_val_exist(dest, i)) {
-		kcdb_buf_set_value(&dest->buf, i, i, NULL, 0);
+		kcdb_buf_set_value(&dest->buf, i, (khm_ui_2) i, NULL, 0);
 
 		rv = KHM_ERROR_SUCCESS;
 	    }
@@ -218,7 +218,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_dup(
     if(KHM_FAILED(kcdb_cred_create(cred->name,
                                    cred->identity,
                                    cred->type,
-                                   &vnewcred))) 
+                                   &vnewcred)))
     {
         code = KHM_ERROR_UNKNOWN;
         goto _exit;
@@ -317,9 +317,9 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_type(
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_set_attrib(
-    khm_handle cred, 
-    wchar_t * name, 
-    void * buffer, 
+    khm_handle cred,
+    const wchar_t * name,
+    void * buffer,
     khm_size cbbuf)
 {
     khm_int32 attr_id = -1;
@@ -335,9 +335,9 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_set_attrib(
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_set_attr(
-    khm_handle vcred, 
-    khm_int32 attr_id, 
-    void * buffer, 
+    khm_handle vcred,
+    khm_int32 attr_id,
+    void * buffer,
     khm_size cbbuf)
 {
     kcdb_cred * cred;
@@ -372,7 +372,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_set_attr(
 
     if (buffer == 0) {
         /* we are removing the value */
-        kcdb_buf_alloc(&cred->buf, attr_id, attr_id, 0);
+        kcdb_buf_alloc(&cred->buf, attr_id, (khm_ui_2) attr_id, 0);
         code = KHM_ERROR_SUCCESS;
         goto _exit;
     }
@@ -393,16 +393,16 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_set_attr(
         goto _exit;
     }
 
-    kcdb_buf_alloc(&cred->buf, attr_id, attr_id, cbdest);
+    kcdb_buf_alloc(&cred->buf, attr_id, (khm_ui_2) attr_id, cbdest);
     if(!kcdb_cred_buf_exist(cred, attr_id)) {
         code = KHM_ERROR_NO_RESOURCES;
         goto _exit;
     }
 
     if(KHM_FAILED(code =
-        type->dup(buffer, cbbuf, kcdb_cred_buf_get(cred,attr_id), &cbdest))) 
+        type->dup(buffer, cbbuf, kcdb_cred_buf_get(cred,attr_id), &cbdest)))
     {
-        kcdb_buf_alloc(&cred->buf, attr_id, attr_id, 0);
+        kcdb_buf_alloc(&cred->buf, attr_id, (khm_ui_2) attr_id, 0);
         goto _exit;
     }
 
@@ -420,11 +420,11 @@ _exit:
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_get_attrib(
-    khm_handle cred, 
-    wchar_t * name, 
+    khm_handle cred,
+    const wchar_t * name,
     khm_int32 * attr_type,
-    void * buffer, 
-    khm_size * cbbuf) 
+    void * buffer,
+    khm_size * cbbuf)
 {
     khm_int32 attr_id = -1;
 
@@ -440,11 +440,11 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_attrib(
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_get_attrib_string(
-    khm_handle cred, 
-    wchar_t * name, 
-    wchar_t * buffer, 
+    khm_handle cred,
+    const wchar_t * name,
+    wchar_t * buffer,
     khm_size * cbbuf,
-    khm_int32 flags) 
+    khm_int32 flags)
 {
     khm_int32 attr_id = -1;
 
@@ -459,11 +459,11 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_attrib_string(
         flags);
 }
 
-KHMEXP khm_int32 KHMAPI 
-kcdb_cred_get_attr(khm_handle vcred, 
+KHMEXP khm_int32 KHMAPI
+kcdb_cred_get_attr(khm_handle vcred,
                    khm_int32 attr_id,
                    khm_int32 * attr_type,
-                   void * buffer, 
+                   void * buffer,
                    khm_size * pcbbuf)
 {
     khm_int32 code = KHM_ERROR_SUCCESS;
@@ -530,9 +530,9 @@ _exit:
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_get_attr_string(
-    khm_handle vcred, 
+    khm_handle vcred,
     khm_int32 attr_id,
-    wchar_t * buffer, 
+    wchar_t * buffer,
     khm_size * pcbbuf,
     khm_int32 flags)
 {
@@ -627,8 +627,8 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_attr_string(
 
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_get_name(
-    khm_handle vcred, 
-    wchar_t * buffer, 
+    khm_handle vcred,
+    wchar_t * buffer,
     khm_size * cbbuf)
 {
     khm_int32 code = KHM_ERROR_SUCCESS;
@@ -639,7 +639,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_name(
         return KHM_ERROR_INVALID_PARAM;
 
     kcdb_cred_lock_read();
-    
+
     if(!kcdb_cred_is_active_cred(vcred)) {
         code = KHM_ERROR_INVALID_PARAM;
         goto _exit;
@@ -671,7 +671,7 @@ _exit:
 }
 
 KHMEXP khm_int32 KHMAPI kcdb_cred_get_identity(
-    khm_handle vcred, 
+    khm_handle vcred,
     khm_handle * identity)
 {
     khm_int32 code = KHM_ERROR_SUCCESS;
@@ -692,7 +692,7 @@ KHMEXP khm_int32 KHMAPI kcdb_cred_get_identity(
     kcdb_identity_hold((khm_handle) cred->identity);
 
     *identity = cred->identity;
-    
+
 _exit:
     kcdb_cred_unlock_read();
     return code;
@@ -739,7 +739,7 @@ _exit:
     kcdb_cred_unlock_write();
 
     kcdb_cred_check_and_delete(vcred);
-    
+
     return code;
 }
 
@@ -809,10 +809,10 @@ _exit:
     return code;
 }
 
-KHMEXP khm_int32 KHMAPI 
-kcdb_creds_comp_attrib(khm_handle cred1, 
-                       khm_handle cred2, 
-                       wchar_t * name)
+KHMEXP khm_int32 KHMAPI
+kcdb_creds_comp_attrib(khm_handle cred1,
+                       khm_handle cred2,
+                       const wchar_t * name)
 {
     khm_int32 attr_id;
 
@@ -822,9 +822,9 @@ kcdb_creds_comp_attrib(khm_handle cred1,
     return kcdb_creds_comp_attr(cred1, cred2, attr_id);
 }
 
-KHMEXP khm_int32 KHMAPI 
-kcdb_creds_comp_attr(khm_handle vcred1, 
-                     khm_handle vcred2, 
+KHMEXP khm_int32 KHMAPI
+kcdb_creds_comp_attr(khm_handle vcred1,
+                     khm_handle vcred2,
                      khm_int32 attr_id)
 {
     khm_int32 code = 0;
@@ -879,11 +879,11 @@ kcdb_creds_comp_attr(khm_handle vcred1,
 
         code = 0;
 
-        if(attrib->compute_cb(vcred1, attr_id, 
+        if(attrib->compute_cb(vcred1, attr_id,
                               NULL, &cb1) != KHM_ERROR_TOO_LONG)
             goto _exit_1;
 
-        if(attrib->compute_cb(vcred2, attr_id, 
+        if(attrib->compute_cb(vcred2, attr_id,
                               NULL, &cb2) != KHM_ERROR_TOO_LONG)
             goto _exit_1;
 
@@ -910,7 +910,7 @@ kcdb_creds_comp_attr(khm_handle vcred1,
         code = type->comp(buf1, cb1,
                           buf2, cb2);
 _exit_1:
-        if(buf1 && (buf1 < (void *)vbuf || 
+        if(buf1 && (buf1 < (void *)vbuf ||
                     buf1 >= (void*)(vbuf + sizeof(vbuf))))
             PFREE(buf1);
         if(buf2 && (buf2 < (void *)vbuf ||
@@ -933,7 +933,7 @@ _exit:
     return code;
 }
 
-KHMEXP khm_int32 KHMAPI 
+KHMEXP khm_int32 KHMAPI
 kcdb_creds_is_equal(khm_handle vcred1,
                     khm_handle vcred2)
 {
@@ -943,12 +943,18 @@ kcdb_creds_is_equal(khm_handle vcred1,
 
     kcdb_cred_lock_read();
     if(!kcdb_cred_is_active_cred(vcred1) ||
-       !kcdb_cred_is_active_cred(vcred2))
+       !kcdb_cred_is_active_cred(vcred2)) {
+
+        code = FALSE;
         goto _exit;
 
+    }
+
     if(vcred1 == vcred2) {
+
         code = TRUE;
         goto _exit;
+
     }
 
     cred1 = vcred1;
@@ -976,7 +982,7 @@ _exit:
     return code;
 }
 
-KHMEXP khm_int32 KHMAPI 
+KHMEXP khm_int32 KHMAPI
 kcdb_cred_get_flags(khm_handle vcred,
                     khm_int32 * pflags)
 {
@@ -1000,13 +1006,13 @@ kcdb_cred_get_flags(khm_handle vcred,
 
     /* Update flags if necessary */
 
-    if (!(f & KCDB_CRED_FLAG_EXPIRED) && 
+    if (!(f & KCDB_CRED_FLAG_EXPIRED) &&
         kcdb_cred_buf_exist(cred, KCDB_ATTR_EXPIRE)) {
 
         FILETIME ftc;
-            
+
         GetSystemTimeAsFileTime(&ftc);
-        if (CompareFileTime(&ftc, ((FILETIME *) 
+        if (CompareFileTime(&ftc, ((FILETIME *)
                                    kcdb_cred_buf_get(cred, KCDB_ATTR_EXPIRE)))
             >= 0)
             f |= KCDB_CRED_FLAG_EXPIRED;
